-- vim: ts=2 sw=2 ai et enc=utf8 fenc=utf8

local RC = RaidChecklist
local P = RaidChecklistPetFamilies

RC.petproviders = { }
for i,b in ipairs (RC.buffs) do RC.petproviders[b] = {} end
for i,b in ipairs (RC.debuffs) do RC.petproviders[b] = {} end
for i,b in ipairs (RC.ccpvps) do RC.petproviders[b] = {} end

local matrix = {
  [P.BAT]         = { "STUN" },
  [P.BEAR]        = { "DEMOROAR" },
  [P.BEETLE]      = { },
  [P.BIRDOFPREY]  = { "DISARM" },
  [P.BOAR]        = { "BLEEDDMGTAKEN" },
  [P.CARRIONBIRD] = { },
  [P.CAT]         = { "AGISTR" },
  [P.CHIMAERA]    = { "SNARE" },
  [P.COREHOUND]   = { "BLOODLUST", "CASTSPD" },
  [P.CRAB]        = { "ROOT" },
  [P.CROCOLISK]   = { "SNARE" },
  [P.DEVILSAUR]   = { "CRIT", "MORTALSTRIKE" },
  [P.DOG]         = { "ROOT" },
  [P.DOOMGUARD]   = { },
  [P.DRAGONHAWK]  = { "SPELLDMGTAKEN" },
  [P.FELGUARD]    = { },
  [P.FELHUNTER]   = { "MANA", "MANAREGEN", "SILENCE" },
  [P.FOX]         = { "ATTACKSPD" },
  [P.GHOUL]       = { },
  [P.GORILLA]     = { "SILENCE" },
  [P.HYENA]       = { "BLEEDDMGTAKEN" },
  [P.IMP]         = { },
  [P.MONKEY]      = { "DISORIENT" },
  [P.MOTH]        = { "SILENCE" },
  [P.NETHERRAY]   = { "SILENCE" },
  [P.RAPTOR]      = { "SUNDER" },
  [P.RAVAGER]     = { "PHYSDMGTAKEN" },
  [P.RHINO]       = { "BLEEDDMGTAKEN", "KNOCKBACK" },
  [P.SCORPID]     = { "DISARM" },
  [P.SERPENT]     = { "SUNDER" },
  [P.SHALESPIDER] = { "STATS" },
  [P.SILITHID]    = { "STAM", "ROOT" },
  [P.SPIDER]      = { "ROOT" },
  [P.SPIRITBEAST] = { "AGISTR" },
  [P.SPOREBAT]    = { "CASTSPD" },
  [P.SUCCUBUS]    = { "KNOCKBACK" },
  [P.TALLSTRIDER] = { "ATTACKSPD" },
  [P.TURTLE]      = { },
  [P.VOIDWALKER]  = { },
  [P.WARPSTALKER] = { "SNARE" },
  [P.WASP]        = { "STUN" },
  [P.WATERELEMENTAL] = { },
  [P.WINDSERPENT] = { "SPELLDMGTAKEN" },
  [P.WOLF]        = { "CRIT" },
  [P.WORM]        = { "PHYSDMGTAKEN", "STUN" },
} 


local function remove_petprovider (rguid)
  for key,guidlist in pairs (RC.petproviders) do
    guidlist[rguid] = nil
  end
  if (RC.OnRefresh) then RC:OnRefresh () end
end


local function add_petprovider (buff, guid)
  RC.petproviders[buff][guid] = true
  if (RC.OnRefresh) then RC:OnRefresh () end
end


local RCB = RaidChecklist.button

function RCB:UNIT_PET (unit)
  local guid = UnitGUID (unit)
  if not guid then return end
  remove_petprovider (guid)
  local family = UnitCreatureFamily (unit.."pet")
  if not family then return end
  local list = matrix[family]
  if not list then
    -- Maybe we haven't got the right family name, or I messed up the locale info...
    DEFAULT_CHAT_FRAME:AddMessage("RaidChecklist: missing family '"..(family or "nil").."', please report this so it can be fixed!")
    return
  end
  for i,key in ipairs (list) do
    add_petprovider (key, guid)
  end
end

RCB:RegisterEvent("UNIT_PET")

